import unittest

class TestCalc(unittest.TestCase):
    def test_addition_works(self):
        pass

    def test_subtraction_works(self):
        pass

    def test_multiplication_works(self):
        pass

    def test_division_works(self):
        pass

if __name__ == '__main__':
    unittest.main()